@@ -1,7 +1,7 @@
 """ imports for BaseModel subclasses
 """
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 from .data_description import (DataDescription, DerivedDataDescription,
                                RawDataDescription)
@@ -14,17 +14,17 @@ from .processing import DataProcess, Processing
 from .subject import LightCycle, Subject
 
 __all__ = [
-    DataDescription,
-    RawDataDescription,
-    DerivedDataDescription,
-    Procedures,
-    EphysRig,
-    EphysSession,
-    Subject,
-    LightCycle,
-    DataProcess,
-    Processing,
-    Acquisition,
-    Instrument,
-    Microscope,
+    'DataDescription',
+    'RawDataDescription',
+    'DerivedDataDescription',
+    'Procedures',
+    'EphysRig',
+    'EphysSession',
+    'Subject',
+    'LightCycle',
+    'DataProcess',
+    'Processing',
+    'Acquisition',
+    'Instrument',
+    'Microscope',
 ]
